use strict;
use Test::More 'no_plan';
use Data::Dumper;
use SQL::Interpolate qw(:all);
require 't/lib.pl';

my $x = 5;
my $v0 = [];
my $v = ['one', 'two'];
my $h0 = {};
my $h = {one => 1, two => 2};

#== INSERT
interp_test(['INSERT INTO mytable', \$x],
            ['INSERT INTO mytable VALUES(?)', undef, $x],
            'INSERT scalarref');
# OK in mysql
interp_test(['INSERT INTO mytable', $v0],
            ['INSERT INTO mytable VALUES()', undef],
            'INSERT arrayref of size = 0');
interp_test(['INSERT INTO mytable', $v],
            ['INSERT INTO mytable VALUES(?, ?)', undef, @$v],
            'INSERT arrayref of size > 0');
# OK in mysql
interp_test(['INSERT INTO mytable', $h0],
            ['INSERT INTO mytable () VALUES()', undef],
            'INSERT hashref of size = 0');
interp_test(['INSERT INTO mytable', $h],
            ['INSERT INTO mytable (one, two) VALUES(?, ?)', undef, 1, 2],
            'INSERT hashref of size > 0');

# IN
# note: 'WHERE field in ()' NOT OK in mysql.
interp_test(['WHERE field IN', \$x],
            ['WHERE field IN (?)', undef, $x],
            'IN scalarref');
interp_test(['WHERE field IN', $v0],
            ['WHERE NULL', undef],
            'IN arrayref of size = 0');
interp_test(['WHERE field IN', $v],
            ['WHERE field IN (?, ?)', undef, @$v],
            'IN arrayref of size > 0');
#FIX-add test--IN hashref is invalid.

# SET
#FIX--add test assert: interp_test(['UPDATE mytable SET', $h0],
interp_test(['UPDATE mytable SET', $h],
            ['UPDATE mytable SET one=?, two=?', undef, 1, 2],
            'SET hashref');

# WHERE
interp_test(['WHERE', $h],
            ['WHERE (one=? AND two=?)', undef, 1, 2],
            'WHERE hashref');

# WHERE x=
interp_test(['WHERE x=', \$x],
            ['WHERE x=?', undef, $x],
            'WHERE x=scalarref');




sub interp_test
{
    my($snips, $expect, $name) = @_;
    is_deeply([dbi_interp @$snips], $expect, $name);
}


